==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/AzureDevOpsScopeEnvironmentDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The AzureDevOps scope connector's environment data
 * @property environmentType The type of the environment data.
 * Expected value is 'AzureDevOpsScope'.
 */
public data class AzureDevOpsScopeEnvironmentDataArgs(
    public val environmentType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs =
        com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs.builder()
            .environmentType(environmentType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureDevOpsScopeEnvironmentDataArgs].
 */
@PulumiTagMarker
public class AzureDevOpsScopeEnvironmentDataArgsBuilder internal constructor() {
    private var environmentType: Output<String>? = null

    /**
     * @param value The type of the environment data.
     * Expected value is 'AzureDevOpsScope'.
     */
    @JvmName("eeibhomhjwgryujo")
    public suspend fun environmentType(`value`: Output<String>) {
        this.environmentType = value
    }

    /**
     * @param value The type of the environment data.
     * Expected value is 'AzureDevOpsScope'.
     */
    @JvmName("lrmwelyayaqpyiph")
    public suspend fun environmentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environmentType = mapped
    }

    internal fun build(): AzureDevOpsScopeEnvironmentDataArgs = AzureDevOpsScopeEnvironmentDataArgs(
        environmentType = environmentType ?: throw PulumiNullFieldException("environmentType"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/AzureDevOpsScopeEnvironmentDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The AzureDevOps scope connector's environment data
 * @property environmentType The type of the environment data.
 * Expected value is 'AzureDevOpsScope'.
 */
public data class AzureDevOpsScopeEnvironmentDataArgs(
    public val environmentType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs =
        com.pulumi.azurenative.security.inputs.AzureDevOpsScopeEnvironmentDataArgs.builder()
            .environmentType(environmentType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureDevOpsScopeEnvironmentDataArgs].
 */
@PulumiTagMarker
public class AzureDevOpsScopeEnvironmentDataArgsBuilder internal constructor() {
    private var environmentType: Output<String>? = null

    /**
     * @param value The type of the environment data.
     * Expected value is 'AzureDevOpsScope'.
     */
    @JvmName("eblvsgmfuuibmrla")
    public suspend fun environmentType(`value`: Output<String>) {
        this.environmentType = value
    }

    /**
     * @param value The type of the environment data.
     * Expected value is 'AzureDevOpsScope'.
     */
    @JvmName("rjquxplinerejarr")
    public suspend fun environmentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environmentType = mapped
    }

    internal fun build(): AzureDevOpsScopeEnvironmentDataArgs = AzureDevOpsScopeEnvironmentDataArgs(
        environmentType = environmentType ?: throw PulumiNullFieldException("environmentType"),
    )
}
